<template>
    <div class="form-group">
        <label v-if="label" :for="id"
            >{{ label }} <span class="text-danger">{{ labelInfo }}</span></label
        >
        <select
            class="custom-select"
            :class="{ error: error }"
            :id="id"
            v-bind="$attrs"
            @input="$emit('input', $event.target.value)"
        >
            <option value="">--{{ labelOption }}--</option>
            <option
                :selected="option.value == selected ? 'selected' : ''"
                v-for="option in options"
                :value="option.value"
                :key="option.value"
            >
                {{ option.text }}
            </option>
        </select>
        <div v-if="error" class="form-error" style="color: red">
            {{ error }}
        </div>
    </div>
</template>

<script>
export default {
    inheritAttrs: false,
    props: {
        id: {
            type: String,
            default() {
                return `input-dropdown-${this._uid}`;
            },
        },
        type: {
            type: String,
            default: "text",
        },
        value: [Number, String],
        label: String,
        labelInfo: String,
        error: String,
        labelOption: String,
        selected: [Number, String],
        options: [],
    },
    methods: {
        focus() {
            this.$refs.input.focus();
        },
        select() {
            this.$refs.input.select();
        },
        setSelectionRange(start, end) {
            this.$refs.input.setSelectionRange(start, end);
        },
    },
};
</script>
